@@ -142,9 +142,9 @@ def get_scene_xml(config, random_seed=0, quiet=False):
         </sensor>''')
 
     confocal_capture = 'false'
-    if v('scan_type') == 'confocal' or v('scan_type') == 'exhaustive':
+    if v('scan_type') == 'confocal':
         confocal_capture = 'true'
-    elif v('scan_type') != 'single':
+    elif v('scan_type') != 'single' and v('scan_type') != 'exhaustive':
         raise AssertionError(
             'scan_type should be one of {single|confocal|exhaustive}')
     sensor_nlos = fdent(f'''\
@@ -523,8 +523,9 @@ def render_nlos_scene(config_path, args):
 
             for x in range(laser_width):
                 for y in range(laser_height):
-                    capture_data.H[:, x, y, ...] = read_mitsuba_streakbitmap(
-                        partial_laser_dir(x + 0.5, y + 0.5))
+                    capture_data.H[:, x, y, ...] = np.squeeze(
+                        read_mitsuba_streakbitmap(
+                            partial_laser_dir(x + 0.5, y + 0.5)))
         else:
             raise AssertionError(
                 'Invalid scan_type, must be one of {single|exhaustive|confocal}')
